=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2007-11-26 08:08:22 +0000
+++ bzrlib/bzrdir.py	2007-11-26 08:54:41 +0000
@@ -49,10 +49,11 @@
     symbol_versioning,
     ui,
     urlutils,
+    win32utils,
+    workingtree,
+    workingtree_4,
     xml4,
     xml5,
-    workingtree,
-    workingtree_4,
     )
 from bzrlib.osutils import (
     sha_strings,
@@ -1357,13 +1358,7 @@
                                       # the covers
                                       mode=temp_control._dir_mode)
         if sys.platform == 'win32' and isinstance(transport, LocalTransport):
-            try:
-                import win32file
-            except ImportError:
-                pass
-            else:
-                win32file.SetFileAttributes(transport._abspath('.bzr'),
-                    win32file.FILE_ATTRIBUTE_HIDDEN)
+            win32utils.set_file_attr_hidden(transport._abspath('.bzr'))
         file_mode = temp_control._file_mode
         del temp_control
         mutter('created control directory in ' + transport.base)

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2007-11-26 08:08:22 +0000
+++ bzrlib/tests/test_bzrdir.py	2007-11-26 08:54:41 +0000
@@ -30,6 +30,7 @@
     repository,
     symbol_versioning,
     urlutils,
+    win32utils,
     workingtree,
     )
 import bzrlib.branch
@@ -43,6 +44,7 @@
 from bzrlib.tests import (
     TestCase,
     TestCaseWithTransport,
+    TestSkipped,
     test_sftp_transport
     )
 from bzrlib.tests.HttpServer import HttpServer
@@ -886,11 +888,15 @@
         return [i.strip() for i in out]
 
     def test_dot_bzr_hidden(self):
+        if sys.platform == 'win32' and not win32utils.has_win32file:
+            raise TestSkipped('unable to make file hidden without pywin32 library')
         b = bzrdir.BzrDir.create('.')
         self.build_tree('a')
         self.assertEquals(['a'], self.get_ls())
 
     def test_dot_bzr_hidden_with_url(self):
+        if sys.platform == 'win32' and not win32utils.has_win32file:
+            raise TestSkipped('unable to make file hidden without pywin32 library')
         b = bzrdir.BzrDir.create(urlutils.local_path_to_url('.'))
         self.build_tree('a')
         self.assertEquals(['a'], self.get_ls())

=== modified file 'bzrlib/win32utils.py'
--- bzrlib/win32utils.py	2007-08-11 05:44:04 +0000
+++ bzrlib/win32utils.py	2007-11-26 08:54:41 +0000
@@ -64,6 +64,11 @@
     else:
         create_buffer = ctypes.create_unicode_buffer
         suffix = 'W'
+try:
+    import win32file
+    has_win32file = True
+except ImportError:
+    has_win32file = False
 
 
 # Special Win32 API constants
@@ -319,3 +324,9 @@
         _winreg.CloseKey(hkey)
 
     return fullpath
+
+
+def set_file_attr_hidden(path):
+    """Set file attributes to hidden if possible"""
+    if has_win32file:
+        win32file.SetFileAttributes(path, win32file.FILE_ATTRIBUTE_HIDDEN)

